from pytest_flask_socketio.fixtures import client_factory
from pytest_flask_socketio.fixtures import client
from pytest_flask_socketio.fixtures import clients
from pytest_flask_socketio.fixtures import _event_receiver
from pytest_flask_socketio.fixtures import DefaultEventReceiver


DEFAULT_NUM_CLIENTS = 5


_clients_fmt_help = 'Specify the data structure for the clients fixture - ' \
                    'one of "list", "alpha", or "num"'

_mark_socketio_help = 'Automatically mark every test using these fixtures ' \
                      'with @pytest.mark.socketio'

# to avoid unused import...
_all_fixtures = [client, clients, client_factory, _event_receiver]


def pytest_addoption(parser):
    parser.addini('clients_fmt', _clients_fmt_help, default='list')
    parser.addini('mark_socketio', _mark_socketio_help, default=True)


def pytest_configure(config):
    config.flask_socketio_clients_fmt = config.getini('clients_fmt')
    config.flask_socketio_num_clients = DEFAULT_NUM_CLIENTS
    config.flask_socketio_event_receiver = DefaultEventReceiver
    config.flask_socketio_automark = config.getini('mark_socketio')
    config.addinivalue_line(
        'markers', 'socketio(num_clients, clients_fmt, recv_wrapper): '
                   'override default values for specific item.'
    )
